#!/bin/sh
# Copyright (C) 2008 - 2010 vortexbox.org
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# Fri Apr 2 2010 Ron Olsen <ronolsen@comcast.net>
# * Fix FormatDrive action:
# - add --force option to sfdisk
# - do dd after sfdisk
# - unmount /backup when done

ACTION=$1
PACKAGE=$2
NOW=`date +'%m/%d/%Y %H:%M:%S'`
function echolog {
echo "`date +'%m/%d/%Y %H:%M:%S'` - $1"
}
 
case $ACTION in
  Reboot )
	echo "Reboot"
	reboot
	;;
	
  PowerDown )
	echo "PowerDown"
	poweroff
	;;
	
  RestartRipper )
	echo "RestartRipper"
	echolog "<b>Restarting Auto Ripper...</b>" >> /var/log/cdrip.log
	service vortexbox stop
	sleep 1
	echolog "<b>Ejecting Disk...</b>" >> /var/log/cdrip.log
	eject
	service vortexbox start
	;;
	
  GetCovers )
	echo "GetCovers"
	echolog "Getting cover art for all your FLACs." >> /var/log/cdrip.log
	/opt/vortexbox/getcoverart
	echolog "Getting cover art for your FLACs complete." >> /var/log/cdrip.log
	;;	
	
  ClearLog )
	echo "ClearLog"
	echolog "Ripper log cleared." > /var/log/cdrip.log
	;;

  ClearMirrorLog )
	echo "ClearMirrorLog"
	echolog "FLAC mirroring log cleared." > /var/log/mirror.log
	;;
	
  ClearUsbBackupLog )
	echo "ClearUsbBackupLog"
	echolog "USB backup log cleared." > /var/log/usbbackup.log
	;;
	
  ClearUpgradeLog )
	echo "ClearUpgradeLog"
	echolog "Upgrade log cleared." > /var/log/vbupgrade.log
	;;
	
  StartMirror )
	echo "StartMirror"
	if [ -f /etc/vortexbox/mirror-flac-mp3.running ]; then
		echo "" >> /var/log/mirror.log
		echolog "Mp3 mirroring allready in progress." >> /var/log/mirror.log
		echo "" >> /var/log/mirror.log
	else
		echo "" >> /var/log/mirror.log
		echolog "Mirroring FLACs to mp3." >> /var/log/mirror.log
		echo "" >> /var/log/mirror.log
		/usr/local/sbin/mirror-flac-mp3 >> /var/log/mirror.log &
	fi
	;;
	
  StartMP4Mirror )
	echo "StartMP4Mirror"
	if [ -f /etc/vortexbox/mirror-flac-aac.running ]; then
		echo "" >> /var/log/mirror.log
		echolog "AAC mirroring allready in progress." >> /var/log/mirror.log
		echo "" >> /var/log/mirror.log
	else
		echo "" >> /var/log/mirror.log
		echolog "Mirroring FLACs to AAC." >> /var/log/mirror.log
		echo "" >> /var/log/mirror.log
		/usr/local/sbin/flac2m4a.sh >> /var/log/mirror.log &
	fi
	;;

  StopMirror )
	echo "StopMirror"
	echo "" >> /var/log/mirror.log
	echolog "FLAC mirroring stopped." >> /var/log/mirror.log
	echo "" >> /var/log/mirror.log
	pkill -f flac2mp3.pl
	pkill -f flac2m4a.sh
	rm /etc/vortexbox/mirror-flac-mp3.running
	rm /etc/vortexbox/mirror-flac-aac.running	
	;;
	
  DelMirror )
	echo "DelMirror"
	echolog "Making sure FLAC mirroring is stopped ." >> /var/log/mirror.log
	pkill -f flac2mp3.pl
	rm /etc/vortexbox/mirror-flac.running
	sleep 3
	echolog "Clearing mp3 files from /storage/music/mp3/." >> /var/log/mirror.log
	rm -rfv /storage/music/mp3/* >> /var/log/mirror.log
	echolog "mp3 files cleared." >> /var/log/mirror.log
	;;	
	
  NewTZ )
	echo "NewTZ"
	echo "ZONE=\"$2\"" > /etc/sysconfig/clock
	rm /etc/localtime2
	ln -sf /usr/share/zoneinfo/$2 /etc/localtime
	/sbin/service ntpd stop
	/usr/sbin/ntpdate pool.ntp.org
	sleep 2
	/usr/sbin/ntpdate pool.ntp.org	
	/sbin/service ntpd start
	;;
	
  SyncTime )
	echo "SyncTime"
	/sbin/service ntpd stop
	/usr/sbin/ntpdate pool.ntp.org
	sleep 2
	/usr/sbin/ntpdate pool.ntp.org	
	/sbin/service ntpd start
	;;
	
  UsbDiskInfo )
	echo "UsbDiskInfo"
	USBDISK=`cat /etc/vortexbox/CurrentUsbDrive.txt` 
	/sbin/fdisk -l $USBDISK | grep -m1 Disk
	;;
	
  FormatDrive )
  	echo "FormatDrive"
	USBDISK=`cat /etc/vortexbox/CurrentUsbDrive.txt`
	echolog "Formatting USB drive $USBDISK with NTFS...++" >> /var/log/usbbackup.log
	/bin/umount /backup
	rm -rf /backup/*
	/bin/dd if=/dev/zero of=${USBDISK}1 bs=512 count=1
	/sbin/sfdisk --force $USBDISK  << EOF
,,7;
EOF
	/usr/sbin/mkntfs -v --label 'VortexBox Backup' -f ${USBDISK}1  >> /var/log/usbbackup.log
	sleep 3
	/bin/mount ${USBDISK}1 /backup
	echo "This is a VortexBox backup drive." > /backup/VortexBox.txt
	echo "Created on $NOW." >> /backup/VortexBox.txt
    /bin/umount /backup
	echolog "Done formatting USB drive $USBDISK." >> /var/log/usbbackup.log
	;;
	
  StopBackup )
  	echo "StopBackup"
	/usr/bin/pkill rsync
    echolog "Backup aborted by user." >> /var/log/usbbackup.log
	;;
	
  BackupStorage )
  	echo "BackupStorage"
	USBDISK=`cat /etc/vortexbox/CurrentUsbDrive.txt` 
	mount ${USBDISK}1 /backup
	sleep 2
	if [ -n "`mount | grep /backup`" ]; then
	  if [ -f "/backup/VortexBox.txt" ]; then
		/opt/vortexbox/dobackup.sh &
	  else
	    echo "" >> /var/log/usbbackup.log
	    echolog "Not a VortexBox backup disk. Please format." >> /var/log/usbbackup.log
		echo "" >> /var/log/usbbackup.log
	  fi
	else
	  echolog "Disk ${USBDISK} in not mounted on /backup. USB disk might need to be formatted." >> /var/log/usbbackup.log
	fi
	;;

 SimplifyMedia )
	echo "SimplifyMedia"
	chkconfig --add simplifymedia
	/sbin/service simplifymedia stop
	rm -rf /opt/simplifymedia/SimplifyPeer.log
	sleep 3
	/sbin/service simplifymedia start
	;;
 
 Upgrade )
	echo "Upgrade"
	echolog "Starting upgrade. (This can take a long time...)" >> /var/log/vbupgrade.log
	yum clean all
	rm -rf /var/cache/yum/*
	rm -rf /var/lib/yum/yumdb/*
	yum -y update --skip-broken >> /var/log/vbupgrade.log
	/opt/vortexbox/vbcleanup.sh
	echolog "Upgrade complete. Please reboot your VortexBox." >> /var/log/vbupgrade.log
	;;

 Install )
	echo "Install"
	/opt/vortexbox/package-scripts/install-$PACKAGE.sh
	;;
 
 Delete )
	echo "Delete"
	/opt/vortexbox/package-scripts/delete-$PACKAGE.sh
	;;		
	
 RestartVBplayer )
	echo "RestartVBplayer"
	/usr/bin/php /opt/vortexbox/mpd_config.php
	;;

 RestartDAAP )
	echo "RestartDAAP"
	cp /var/tmp/forked-daapd.conf /etc
	/sbin/service forked-daapd stop
	sleep 2
	/sbin/service forked-daapd start
	;;

 DAAPDeleteDatabase )
	/sbin/service forked-daapd stop
	sleep 2
	rm -rf /var/cache/forked-daapd/songs3.db
	sleep 2
	/sbin/service forked-daapd start
	;;	
	
 RestartDLNA )
	echo "RestartDLNA"
	cp /var/tmp/minidlna.conf /etc
	/sbin/service minidlna stop
	sleep 3
	 /usr/sbin/minidlna -R
	;;
 
 RescanDLNA )
	echo "RescanDLNA"
	/sbin/service minidlna stop
	sleep 3
	 /usr/sbin/minidlna -R
	;;
	
 ServiceStop )
	echo "ServiceStop"
	/sbin/service $PACKAGE stop
	;;

 ServiceStart )
	echo "ServiceStart"
	/sbin/service $PACKAGE start
	;;
 
 ServiceStatus )
	/sbin/service $PACKAGE status  2> /dev/null | grep running >/dev/null 2>&1
 	if [ $? -eq 0 ]; then
	  STATUS="Running"
	else
	  STATUS="Unknown"
	fi
	/sbin/service $PACKAGE status  2> /dev/null | grep stopped >/dev/null 2>&1
 	if [ $? -eq 0 ]; then
	  STATUS="Stopped"
	fi
	echo $STATUS
	;;	
	
esac
